# Local libraries
require "#{RAILS_ROOT}/lib/has_many_through_dependent"
require "#{RAILS_ROOT}/lib/association_collection_dependent"
require "#{RAILS_ROOT}/lib/has_parameters"
require "#{RAILS_ROOT}/lib/active_model_scopes"
require "#{RAILS_ROOT}/lib/puppet/report"
require "#{RAILS_ROOT}/lib/csv_extensions"
